@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::DataPrinter::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::DataPrinter::VERSION = '0.05';
+  $Reply::Plugin::DataPrinter::VERSION = '0.06';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ use warnings;
 
 use base 'Reply::Plugin';
 
-use Data::Printer;
+use Data::Printer alias => 'p';
 
 
 sub mangle_result {
@@ -31,7 +31,7 @@ Reply::Plugin::DataPrinter - format results using Data::Printer
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
